==> dl.php?src=linea21_1_4.zip: linea21/sdi/help.php <==
<?php
/**
 * @package linea21.modules
 * @subpackage sdi
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!function_exists('AuthenthificationProcess')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

$dirbox = $dir . "/help";
?>
<br
	class="brendstep brendstepfooter" />
<div class="headerhelp"><a href="#aideencre"
	title="<?php echo _t('help','title');?>" class="help_ico aideencre"></a>
<div class="help"><a href="#aideencre" class="aideencre" id="aideencre"
	title="<?php echo _t('help','title');?>"><?php echo _t('help','title');?></a>
<?if ($todo == 'add') {
  ?>
<div id="aide">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('sdi','add');?></p>
<ul>
	<li><?php echo _t('sdi','help_add1');?></li>
	<li><?php echo _t('sdi','help_add2');?></li>
	<li><?php echo _t('sdi','help_add5');?></li>
	<li><?php echo _t('sdi','help_add6');?></li>
	<li><?php echo _t('sdi','help_add3');?></li>
	<li><?php echo _t('sdi','help_add4');?></li>
</ul>

  <?php }
  if ($todo == 'det') {
    ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('sdi','det');?></p>
<ul>
	<li><?php echo _t('sdi','help_det1');?></li>
	<li><?php echo _t('sdi','help_det2');?></li>
	<li><?php echo _t('sdi','help_det3');?></li>
	<li><?php echo _t('sdi','help_det4');?></li>
	<li><?php echo _t('sdi','help_det5');?></li>

</ul>

    <?php }
    if ($todo == 'mod') {
      ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('sdi','mod');?></p>
<ul>
	<li><?php echo _t('sdi','help_mod1');?></li>
	<li><?php echo _t('sdi','help_mod2');?></li>
	<li><?php echo _t('sdi','help_mod3');?></li>
	<li><?php echo _t('sdi','help_mod4');?></li>
</ul>
      <?php }
      if ($todo == 'mod_p') {
        ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('sdi','mod_p');?></p>
<ul>
	<li><?php echo _t('sdi','help_mod_p1');?></li>
	<li><?php echo _t('sdi','help_mod2');?></li>
	<li><?php echo _t('sdi','help_mod3');?></li>
	<li><?php echo _t('sdi','help_mod5');?></li>
</ul>
        <?php }

        if ($todo == 'mod_e') {
          ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('sdi','mod_e');?></p>
<ul>
	<li><?php echo _t('sdi','help_mod_e1');?></li>
	<li><?php echo _t('sdi','help_mod2');?></li>
	<li><?php echo _t('sdi','help_mod3');?></li>
	<li><?php echo _t('sdi','help_mod5');?></li>
</ul>
          <?php }
          if ($todo == 'mod_r') {
            ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('sdi','mod_r');?></p>
<ul>
	<li><?php echo _t('sdi','help_mod_r1');?></li>
	<li><?php echo _t('sdi','help_mod2');?></li>
	<li><?php echo _t('sdi','help_mod3');?></li>
	<li><?php echo _t('sdi','help_mod5');?></li>
</ul>
            <?php }

            if ($todo == 'list') {
              ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('sdi','list');?></p>
<ul>
	<li><?php echo _t('sdi','help_list1');?></li>
	<li><?php echo _t('sdi','help_list2');?></li>
	<li><?php echo _t('sdi','help_list3');?></li>
	<li><?php echo _t('sdi','help_list4');?></li>
	<li><?php echo _t('sdi','help_list5');?></li>
</ul>
              <?php }
              if ($todo == 'sup') {
                ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('sdi','sup');?></p>
<ul>
	<li><?php echo _t('sdi','help_sup1');?></li>
	<li><?php echo _t('sdi','help_sup2');?></li>
</ul>
<?php }
include_once(THEME_ADMIN_PATH."footer_content.php");
?>

==> dl.php?src=linea21_1_6.zip: linea21/sdi/help.php <==
<?php
/**
 * @package linea21.modules
 * @subpackage sdi
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

$dirbox = $dir . "/help";
?>
<br
	class="brendstep brendstepfooter" />
<div class="headerhelp"><a href="#aide-ancre"
	title="<?php echo _t('help','title');?>" class="help_ico aide-ancre"></a>
<div class="help"><a href="#aide-ancre" class="aide-ancre" id="aide-ancre"
	title="<?php echo _t('help','title');?>"><?php echo _t('help','title');?></a>
<?php if ($todo == 'add') {
  ?>
<div id="aide">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('sdi','add');?></p>
<ul>
	<li><?php echo _t('sdi','help_add1');?></li>
	<li><?php echo _t('sdi','help_add2');?></li>
	<li><?php echo _t('sdi','help_add5');?></li>
	<li><?php echo _t('sdi','help_add6');?></li>
	<li><?php echo _t('sdi','help_add3');?></li>
	<li><?php echo _t('sdi','help_add4');?></li>
</ul>

  <?php }
  if ($todo == 'det') {
    ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('sdi','det');?></p>
<ul>
	<li><?php echo _t('sdi','help_det1');?></li>
	<li><?php echo _t('sdi','help_det2');?></li>
	<li><?php echo _t('sdi','help_det3');?></li>
	<li><?php echo _t('sdi','help_det4');?></li>
	<li><?php echo _t('sdi','help_det5');?></li>

</ul>

    <?php }
    if ($todo == 'mod') {
      ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('sdi','mod');?></p>
<ul>
	<li><?php echo _t('sdi','help_mod1');?></li>
	<li><?php echo _t('sdi','help_mod2');?></li>
	<li><?php echo _t('sdi','help_mod3');?></li>
	<li><?php echo _t('sdi','help_mod4');?></li>
</ul>
      <?php }
      if ($todo == 'mod_p') {
        ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('sdi','mod_p');?></p>
<ul>
	<li><?php echo _t('sdi','help_mod_p1');?></li>
	<li><?php echo _t('sdi','help_mod2');?></li>
	<li><?php echo _t('sdi','help_mod3');?></li>
	<li><?php echo _t('sdi','help_mod5');?></li>
</ul>
        <?php }

        if ($todo == 'mod_e') {
          ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('sdi','mod_e');?></p>
<ul>
	<li><?php echo _t('sdi','help_mod_e1');?></li>
	<li><?php echo _t('sdi','help_mod2');?></li>
	<li><?php echo _t('sdi','help_mod3');?></li>
	<li><?php echo _t('sdi','help_mod5');?></li>
</ul>
          <?php }
          if ($todo == 'mod_r') {
            ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('sdi','mod_r');?></p>
<ul>
	<li><?php echo _t('sdi','help_mod_r1');?></li>
	<li><?php echo _t('sdi','help_mod2');?></li>
	<li><?php echo _t('sdi','help_mod3');?></li>
	<li><?php echo _t('sdi','help_mod5');?></li>
</ul>
            <?php }

            if ($todo == 'list') {
              ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('sdi','list');?></p>
<ul>
	<li><?php echo _t('sdi','help_list1');?></li>
	<li><?php echo _t('sdi','help_list2');?></li>
	<li><?php echo _t('sdi','help_list3');?></li>
	<li><?php echo _t('sdi','help_list4');?></li>
	<li><?php echo _t('sdi','help_list5');?></li>
</ul>
              <?php }
              if ($todo == 'sup') {
                ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('sdi','sup');?></p>
<ul>
	<li><?php echo _t('sdi','help_sup1');?></li>
	<li><?php echo _t('sdi','help_sup2');?></li>
</ul>
<?php }
include_once(THEME_ADMIN_PATH."footer_content.php");
?>
